#define MNID_FILE_OPEN          0x101
#define MNID_FILE_PRINT         0x104
#define MNID_FILE_SETUP         0x106
#define MNID_FILE_EXIT          0x108

#define MNID_EDIT_COPYDLG       0x111
#define MNID_EDIT_ANNOTATE      0x112

#define MNID_BKMK_DEFINE        0x121

#define MNID_HELP_HELPON        0x131
#define MNID_HELP_HELPTOP       0x132
#define MNID_HELP_ABOUT         0x141
#define MNID_HELP_WINE          0x142

#define MAIN_MENU		0x10F

#define STID_WINE_HELP		0x120
#define STID_WHERROR		0x121
#define STID_WARNING  		0x122
#define STID_INFO  		0x123
#define STID_NOT_IMPLEMENTED 	0x124
#define STID_HLPFILE_ERROR_s 	0x125
#define STID_CONTENTS 		0x126
#define STID_SEARCH	 	0x127
#define STID_BACK 		0x128
#define STID_HISTORY 		0x129
#define STID_TOPICS 		0x12A
#define STID_ALL_FILES 		0x12B
#define STID_HELP_FILES_HLP	0x12C
#define STID_DIALOG_TEST	0x12D
#define STID_FILE_NOT_FOUND_s	0x12E

#define IDD_INDEX               0x150
#define IDC_INDEXLIST           0x151
